# (akien) Partially synced with Fedora (patches, license checks, manpage).

# "fix" underlinking:
%define _disable_ld_no_undefined 1


# http://trac.wildfiregames.com/wiki/BuildInstructions#Linux

# (akien) Can't use system mozjs78 for now due to two linking issues:
# * https://bugzilla.mozilla.org/show_bug.cgi?id=1644600
# * https://code.wildfiregames.com/D3127
# + needs some trivial fixes to upgrade usage to 78.7, see Patch11 and
#   https://trac.wildfiregames.com/ticket/5986#comment:1

# Does not build with mozjs-78
# source/scriptinterface/ScriptTypes.h:85:2: error: #error Your compiler is trying to use an untested minor version of the SpiderMonkey library. If you are a package maintainer, please make sure to check very carefully that this version does not change the behaviour of the code executed by SpiderMonkey. Different parts of the game (e.g. the multiplayer mode) rely on deterministic behaviour of the JavaScript engine. A simple way for testing this would be playing a network game with one player using the old version and one player using the new version. Another way for testing is running replays and comparing the final hash (check trac.wildfiregames.com/wiki/Debugging#Replaymode). For more information check this link: trac.wildfiregames.com/wiki/Debugging#Outofsync
# Check source/scriptinterface/ScriptTypes.h for mozjs version requirement.
%bcond_with	system_mozjs78

# Exclude private libraries from autogenerated provides and requires
%global __provides_exclude_from ^%{_libdir}/0ad/
%global __requires_exclude ^(libAtlasUI.*\.so|libCollada.*\.so|libmozjs78.*\.so)

Name:		0ad
Epoch:		1
Version:	0.0.25
Release:	%mkrel 1
License:	GPLv2+ and BSD and MIT and IBM and MPLv2.0
Group:		Games/Strategy
Summary:	Cross-Platform RTS Game of Ancient Warfare
Url:		http://play0ad.com/
Source0:	https://releases.wildfiregames.com/%{name}-%{version}-alpha-unix-build.tar.xz
Source1:	https://releases.wildfiregames.com/%{name}-%{version}-alpha-unix-build.tar.xz.sha1sum
# adapted from binaries/system/readme.txt
# It is advisable to review this file on newer versions, to update the
# version field and check for extra options. Note that windows specific,
# and disabled options were not added to the manual page.
Source2:	%{name}.6

BuildRequires:	boost-devel
BuildRequires:	cmake
BuildRequires:	icu-devel
BuildRequires:	miniupnpc-devel
BuildRequires:	pkgconfig(gloox)
BuildRequires:	pkgconfig(fmt)
BuildRequires:	pkgconfig(libcurl)
BuildRequires:	pkgconfig(libenet)
BuildRequires:	pkgconfig(libjpeg)
BuildRequires:	pkgconfig(libpng)
BuildRequires:	pkgconfig(libsodium)
BuildRequires:	pkgconfig(libxml-2.0)
BuildRequires:	pkgconfig(openal)
BuildRequires:	pkgconfig(sdl2)
BuildRequires:	pkgconfig(valgrind)
BuildRequires:	pkgconfig(vorbisfile)
BuildRequires:	pkgconfig(xcursor)
BuildRequires:	python2
BuildRequires:	wxgtk-devel

%if %{without system_mozjs78}
# bundled mozjs
BuildRequires:	pkgconfig(nspr)
BuildRequires:	pkgconfig(libffi)
BuildRequires:	pkgconfig(zlib)
BuildRequires:	readline-devel
BuildRequires:	rustc
BuildRequires:	cargo
BuildRequires:	zip
%else
BuildRequires:	pkgconfig(mozjs-78)
%endif

# bundled mozjs: For build time tests only
BuildRequires:	python-devel
BuildRequires:	perl-devel
BuildRequires:	make

ExclusiveArch:	x86_64 %{arm} aarch64 ppc64le

%if %{without system_mozjs78}
Provides: bundled(mozjs) = 78
%endif

Requires:	%{name}-data = %{epoch}:%{version}

# Only do fcollada debug build with enabling debug maintainer mode
# It also prevents assumption there that it is building in x86
Patch1:		%{name}-debug.patch
# https://bugzilla.redhat.com/show_bug.cgi?id=1141464
Patch2:		%{name}-valgrind.patch

#
# Mageia patches
#
# Fix support for i586 host (same patch as in mozjs78 system package).
Patch10:	0ad-0.0.25b-fix-mozjs78-i586-build.patch

%description
0 A.D. (pronounced "zero ey-dee") is a free, open-source, cross-platform
real-time strategy (RTS) game of ancient warfare. In short, it is a
historically-based war/economy game that allows players to relive or rewrite
the history of Western civilizations, focusing on the years between 500 B.C.
and 500 A.D. The project is highly ambitious, involving state-of-the-art 3D
graphics, detailed artwork, sound, and a flexible and powerful custom-built
game engine.

The game has been in development by Wildfire Games (WFG), a group of volunteer,
hobbyist game developers, since 2001.

%prep
%setup -q -n %{name}-%{version}-alpha

%patch1 -p0
%patch2 -p0
%if %{without system_mozjs78}
%patch10 -p1
%endif

rm -fr libraries/source/valgrind
# (tv) prevent underlinking
sed -i 's!-Wl,--no-undefined!!' build/premake/premake5.lua

%build
%set_build_flags
build/workspaces/update-workspaces.sh \
    --bindir=%{_bindir} \
    --datadir=%{_gamesdatadir}/%{name} \
    --libdir=%{_libdir}/%{name} \
%if %{with system_mozjs78}
    --with-system-mozjs \
%endif
    --without-nvtt

%make_build -C build/workspaces/gcc config=release verbose=1

%check
# test fails as they requires libraries already installed
#export LD_LIBRARY_PATH=%{buildroot}%{_libdir}/%{name}
#./binaries/system/test

%install
install -d %{buildroot}%{_bindir}
install -m755 binaries/system/pyrogenesis %{buildroot}%{_bindir}/pyrogenesis
install -m755 build/resources/0ad.sh      %{buildroot}%{_bindir}/%{name}

install -d %{buildroot}%{_libdir}/%{name}
for name in AtlasUI Collada; do
    install -p -m 755 binaries/system/lib${name}.so %{buildroot}%{_libdir}/%{name}/lib${name}.so
done

%if %{without system_mozjs78}
name=mozjs78-ps-release
install -p -m 755 binaries/system/lib${name}.so %{buildroot}%{_libdir}/%{name}/lib${name}.so
%endif

install -D -m644 build/resources/%{name}.desktop %{buildroot}%{_datadir}/applications/%{name}.desktop
install -D -m644 build/resources/%{name}.appdata.xml %{buildroot}%{_datadir}/appdata/%{name}.appdata.xml
install -D -m644 build/resources/%{name}.png %{buildroot}%{_iconsdir}/hicolor/128x128/apps/%{name}.png

install -d %{buildroot}%{_gamesdatadir}/%{name}
cp -a binaries/data/* %{buildroot}%{_gamesdatadir}/%{name}

install -D -m644 %{_sourcedir}/%{name}.6 %{buildroot}%{_mandir}/man6/%{name}.6
ln -sf %{name}.6 %{buildroot}%{_mandir}/man6/pyrogenesis.6

%files
%doc README.txt LICENSE.txt
%{_bindir}/%{name}
%{_bindir}/pyrogenesis
%{_gamesdatadir}/%{name}/
%{_libdir}/%{name}/
%{_datadir}/appdata/%{name}.appdata.xml
%{_datadir}/applications/%{name}.desktop
%{_iconsdir}/hicolor/128x128/apps/%{name}.png
%{_mandir}/man6/*.6*


%changelog
* Sun Aug 08 2021 akien <akien> 1:0.0.25-1.mga8
+ Revision: 1740707
- Version 0.0.25
- Version 0.0.24b

* Fri Jan 01 2021 wally <wally> 1:0.0.23b-16.mga8
+ Revision: 1667684
- rebuild for wxgtk pre 3.1.5 snapshot

* Thu Dec 31 2020 wally <wally> 1:0.0.23b-15.mga8
+ Revision: 1666731
- rebuild for boost 1.75.0

* Sat Dec 26 2020 daviddavid <daviddavid> 1:0.0.23b-14.mga8
+ Revision: 1663832
- rebuild for new gloox 1.0.24

* Sun Dec 20 2020 wally <wally> 1:0.0.23b-13.mga8
+ Revision: 1661973
- rebuild for boost 1.74.0

* Mon Nov 30 2020 luigiwalser <luigiwalser> 1:0.0.23b-12.mga8
+ Revision: 1651008
- ICU 68 uses standard C++ bool true
- rebuild for icu

* Sun Aug 16 2020 wally <wally> 1:0.0.23b-11.mga8
+ Revision: 1614321
- rebuild for new wxgtk 3.1.4

* Wed Jul 01 2020 wally <wally> 1:0.0.23b-10.mga8
+ Revision: 1601008
- rebuild for icu 67.1

* Wed May 13 2020 tv <tv> 1:0.0.23b-9.mga8
+ Revision: 1583556
- fix build with gcc-10

* Sun May 03 2020 wally <wally> 1:0.0.23b-8.mga8
+ Revision: 1578027
- rebuild for boost 1.73.0

* Sat Apr 04 2020 wally <wally> 1:0.0.23b-7.mga8
+ Revision: 1564443
- rebuild for new icu 66.1

* Wed Feb 19 2020 umeabot <umeabot> 1:0.0.23b-6.mga8
+ Revision: 1544574
- Mageia 8 Mass Rebuild

* Sun Jan 26 2020 wally <wally> 1:0.0.23b-5.mga8
+ Revision: 1483337
- rebuild for boost 1.72.0
- replace deprecated %%setup_compile_flags

* Tue Nov 12 2019 wally <wally> 1:0.0.23b-4.mga8
+ Revision: 1459447
- rebuild for wxgtk 3.1.3

* Sat Oct 05 2019 daviddavid <daviddavid> 1:0.0.23b-3.mga8
+ Revision: 1449429
- rebuild for new icu 65.1

* Wed Jul 17 2019 wally <wally> 1:0.0.23b-2.mga8
+ Revision: 1422205
- rebuild with gtk3 enabled wxgtk 3.1.2

* Sun Dec 30 2018 akien <akien> 1:0.0.23b-1.mga7
+ Revision: 1347061
- Version 0.0.23b

* Sat Dec 29 2018 luigiwalser <luigiwalser> 1:0.0.23-7.mga7
+ Revision: 1346081
- rebuild for icu

* Tue Oct 16 2018 wally <wally> 1:0.0.23-6.mga7
+ Revision: 1321004
- rebuild for new boost 1.68.0

* Sat Sep 22 2018 umeabot <umeabot> 1:0.0.23-5.mga7
+ Revision: 1296574
- Mageia 7 Mass Rebuild

* Fri Aug 24 2018 daviddavid <daviddavid> 1:0.0.23-4.mga7
+ Revision: 1253803
- rebuild for new miniupnpc 2.1

* Mon Aug 20 2018 tv <tv> 1:0.0.23-3.mga7
+ Revision: 1253003
- rebuild with latest icu

* Tue Jul 31 2018 pterjan <pterjan> 1:0.0.23-2.mga7
+ Revision: 1246465
- Add Fedora patch allowing to build against system mozjs38

* Fri May 18 2018 akien <akien> 1:0.0.23-1.mga7
+ Revision: 1230277
- Build against system mozjs38
- Alpha 23

* Fri Dec 29 2017 wally <wally> 1:0.0.22-8.mga7
+ Revision: 1186956
- rebuild for new icu

* Mon Dec 25 2017 wally <wally> 1:0.0.22-7.mga7
+ Revision: 1184647
- rebuild for new boost

* Sun Nov 19 2017 tv <tv> 1:0.0.22-6.mga7
+ Revision: 1177750
- rebuild for boost 1.65

* Sat Sep 16 2017 tv <tv> 1:0.0.22-5.mga7
+ Revision: 1154530
- rebuild with latest boost

* Thu Aug 17 2017 sander85 <sander85> 1:0.0.22-4.mga7
+ Revision: 1141328
- Rebuild for new gloox

* Tue Aug 01 2017 pterjan <pterjan> 1:0.0.22-3.mga7
+ Revision: 1133467
- Fix for new find_lang

* Thu Jul 27 2017 akien <akien> 1:0.0.22-2.mga7
+ Revision: 1131533
- Make data Requires more explicit to avoid version mismatch (mga#19555)

* Thu Jul 27 2017 akien <akien> 1:0.0.22-1.mga7
+ Revision: 1131386
- Alpha 22

* Sat Jun 03 2017 akien <akien> 1:0.0.21-7.mga6
+ Revision: 1106079
- Rebuild for wxgtk 3.0.3.1

* Tue May 16 2017 neoclust <neoclust> 1:0.0.21-6.mga6
+ Revision: 1102007
- Rebuild against new miniupnpc

* Tue May 16 2017 neoclust <neoclust> 1:0.0.21-5.mga6
+ Revision: 1101999
- Rebuild against new miniupnpc

* Mon Mar 20 2017 akien <akien> 1:0.0.21-4.mga6
+ Revision: 1093674
- Rebuild for icu 58.2

* Sat Jan 28 2017 akien <akien> 1:0.0.21-3.mga6
+ Revision: 1083859
- Rebuild for buildsystem issue

* Wed Dec 21 2016 tv <tv> 1:0.0.21-2.mga6
+ Revision: 1076256
- move back binary in %%_bindir else desktop entry is useless & hidden...

* Fri Nov 11 2016 akien <akien> 1:0.0.21-1.mga6
+ Revision: 1066330
- Alpha 21

* Thu Jun 02 2016 daviddavid <daviddavid> 1:0.0.20-3.mga6
+ Revision: 1019799
- rebuild for wxgtk3.0 built with GTK2

* Sat May 14 2016 tv <tv> 1:0.0.20-2.mga6
+ Revision: 1015484
- rebuild for new icu
- kill useless macro

* Fri Apr 01 2016 akien <akien> 1:0.0.20-1.mga6
+ Revision: 997300
- Alpha 20

* Wed Jan 13 2016 luigiwalser <luigiwalser> 1:0.0.19-4.mga6
+ Revision: 922365
- rebuild for gloox

* Fri Jan 01 2016 luigiwalser <luigiwalser> 1:0.0.19-3.mga6
+ Revision: 917812
- rebuild for icu

* Sat Dec 26 2015 fwang <fwang> 1:0.0.19-2.mga6
+ Revision: 915080
- rebuild for new boost

* Sun Nov 29 2015 akien <akien> 1:0.0.19-1.mga6
+ Revision: 906997
- Build with wxgtk 3.0
- Remove upstreamed patches
- Build against SDL2
- Alpha 19

* Wed Nov 25 2015 pterjan <pterjan> 1:0.0.18-8.mga6
+ Revision: 905877
- valgring can actually be built on armv5tl

* Fri Nov 13 2015 pterjan <pterjan> 1:0.0.18-7.mga6
+ Revision: 902974
- Do not require valgrind on arm

* Tue Oct 13 2015 fwang <fwang> 1:0.0.18-6.mga6
+ Revision: 890220
- add upstream patch to build with latest miniupnpc
- rebuild for new miniupnpc

* Fri Sep 25 2015 fwang <fwang> 1:0.0.18-5.mga6
+ Revision: 883483
- rebuild for new boost

* Sun Sep 06 2015 akien <akien> 1:0.0.18-4.mga6
+ Revision: 873770
- Rebuild for gcc 5.2.1

* Fri Jul 31 2015 fwang <fwang> 1:0.0.18-3.mga6
+ Revision: 859461
- rebuild for new boost

* Sat Jul 25 2015 tv <tv> 1:0.0.18-2.mga6
+ Revision: 857391
- rebuild for new libicu

* Sat Mar 14 2015 akien <akien> 1:0.0.18-1.mga5
+ Revision: 818499
- Alpha 18 Rhododactylos
- Build against bundled mozjs31 since it is not package in Mageia 5

* Wed Dec 17 2014 akien <akien> 1:0.0.17-0.alpha.3.mga5
+ Revision: 803763
- Rebuild for miniupnpc

* Wed Oct 15 2014 umeabot <umeabot> 1:0.0.17-0.alpha.2.mga5
+ Revision: 740301
- Second Mageia 5 Mass Rebuild

* Tue Oct 14 2014 akien <akien> 1:0.0.17-0.alpha.1.mga5
+ Revision: 738717
- Alpha 17 Quercus
- Build against system valgrind (patch from Fedora)

* Tue Sep 16 2014 umeabot <umeabot> 1:0.0.16-0.alpha.4.mga5
+ Revision: 677626
- Mageia 5 Mass Rebuild

* Tue Aug 26 2014 luigiwalser <luigiwalser> 1:0.0.16-0.alpha.3.mga5
+ Revision: 668386
- rebuild

* Fri May 30 2014 guillomovitch <guillomovitch> 1:0.0.16-0.alpha.2.mga5
+ Revision: 627796
- add missing data files

* Thu May 29 2014 guillomovitch <guillomovitch> 1:0.0.16-0.alpha.1.mga5
+ Revision: 627720
- disable failing tests
- add man page, stolen from Fedora
+ dams <dams>
- new version alpha 16
- rebuild for new 'miniupnpc'
+ akien <akien>
- Add Fedora patch to workaround %%check failure with gcc 4.9
+ luigiwalser <luigiwalser>
- add patch from fedora to allow building with miniupnpc 1.9
- rebuild for miniupnpc

* Fri Feb 14 2014 fwang <fwang> 1:0.0.15-0.alpha.3.mga5
+ Revision: 591039
- force wxgtk 2.8
- add upstream patch to build with wxwidgets 3.0
- try build with wxwidgets 3.0
+ barjac <barjac>
- rebuild against boost-1.55

* Tue Feb 04 2014 dams <dams> 1:0.0.15-0.alpha.1.mga5
+ Revision: 581333
- update BR (miniupnpc)
- new version aplha 15
- update BR (gloox)
- add appdata file

* Sat Oct 19 2013 umeabot <umeabot> 1:0.0.14-0.alpha.2.mga4
+ Revision: 533792
- Mageia 4 Mass Rebuild

* Fri Sep 06 2013 dams <dams> 1:0.0.14-0.alpha.1.mga4
+ Revision: 475443
- new version alpha 14

* Mon Jul 08 2013 fwang <fwang> 1:0.0.13-0.alpha.4.mga4
+ Revision: 451140
- rebuild for new boost

* Mon Jun 03 2013 fwang <fwang> 1:0.0.13-0.alpha.3.mga4
+ Revision: 435530
- rebuild for new libpng

* Wed Apr 10 2013 dams <dams> 1:0.0.13-0.alpha.2.mga3
+ Revision: 409473
- rebuild for new boost

* Fri Apr 05 2013 dams <dams> 1:0.0.13-0.alpha.1.mga3
+ Revision: 408206
- new version: alpha 13

* Fri Jan 11 2013 umeabot <umeabot> 1:0.0.12-0.alpha.3.mga3
+ Revision: 345042
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Wed Dec 19 2012 kamil <kamil> 1:0.0.12-0.alpha.2.mga3
+ Revision: 332905
- rebuild against boost 1.52.0

* Wed Dec 19 2012 dams <dams> 1:0.0.12-0.alpha.1.mga3
+ Revision: 332858
- new version 0.0.12
- update %%version to follow upstream version

* Sun Sep 09 2012 dams <dams> 1.0-1.alpha11.mga3
+ Revision: 291316
- new version alpha11
- remove useless patchs
- update specfile

* Fri Aug 03 2012 fwang <fwang> 1.0-0.11863.5.mga3
+ Revision: 278185
- update boost libname
- fix build with boost 1.50
- br libjs
- rebuild for new boost

* Fri Jun 08 2012 dams <dams> 1.0-0.11863.4.mga3
+ Revision: 257623
- fix '.desktop'

* Thu Jun 07 2012 dams <dams> 1.0-0.11863.3.mga3
+ Revision: 257100
- update specfile to use 'gamesdatadir' and 'gamesbindir'
- fix require en 'Oad-data'
- add 'gamin-devel' instead of 'fam-devel' as it deprecated
- add 'mozjs185-devel' as a 'BuildRequires'
- fix build options (was missing '=' before path)
- do not use 'enet' and 'mozjs185' from the tarball but from system

* Sun Jun 03 2012 wally <wally> 1.0-0.11863.2.mga3
+ Revision: 253778
- rebuild for new enet

* Fri Jun 01 2012 dams <dams> 1.0-0.11863.1.mga3
+ Revision: 252587
- new version alpha 10 rev 11863

* Tue May 29 2012 kamil <kamil> 1.0-0.10803.3.mga3
+ Revision: 248945
- rebuild against boost 1.49.0

* Wed Dec 28 2011 dmorgan <dmorgan> 1.0-0.10803.2.mga2
+ Revision: 188462
- Rebuild against new libtiff
+ guillomovitch <guillomovitch>
- new alpha version

* Fri Dec 16 2011 wally <wally> 1.0-0.10288.4.mga2
+ Revision: 182844
- use unicode version of wxgtk
- drop duplicate BRs
- wxGTK-devel BR was renamed to wxgtk-devel

* Mon Nov 28 2011 fwang <fwang> 1.0-0.10288.3.mga2
+ Revision: 173548
- rebuild for new boost

* Sun Sep 25 2011 wally <wally> 1.0-0.10288.2.mga2
+ Revision: 147663
- build with system enet

* Tue Sep 20 2011 mikala <mikala> 1.0-0.10288.1.mga2
+ Revision: 146051
- update tarball to Alpha 7 Geronium ( revision 10288)
- remove %%clean section &  %%defattr
- Fix license
- Fix files list
- Drop patchs merged upstream

* Mon Sep 12 2011 fwang <fwang> 1.0-0.09786.2.mga2
+ Revision: 142618
- fix build with libpng1.5
- rebuild for new libpng
- install libenet
- do not use system enet (it requires enet 1.3, which is n/a)
- data package becomes seperated source package
- add upstream patch to build with boost 1.47
- new snapshot 09786
- rebuild for new boost
+ ahmad <ahmad>
- Rebuild against wxgtk2.8 with enabled catch_segvs

* Wed Jun 22 2011 fwang <fwang> 1.0-0.09488.2.mga2
+ Revision: 111857
- rebuild for new boost

* Sun May 08 2011 mikala <mikala> 1.0-0.09488.1.mga1
+ Revision: 96555
- imported package 0ad


* Mon Mar 14 2011 Funda Wang <fwang@mandriva.org> 1.0-0.8899.2mdv2011.0
+ Revision: 644467
- rebuild for new boost

* Mon Feb 14 2011 Guillaume Rousse <guillomovitch@mandriva.org> 1.0-0.8899.1
+ Revision: 637689
- new snapshot
- produce data package from the same snapshot

* Wed Oct 20 2010 Guillaume Rousse <guillomovitch@mandriva.org> 1.0-0.08413.1mdv2011.0
+ Revision: 587053
- import 0ad

